package com.zcxk.charge.web;

import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.cloud.client.discovery.EnableDiscoveryClient;
import org.springframework.cloud.client.loadbalancer.LoadBalanced;
import org.springframework.context.annotation.Bean;
import org.springframework.web.client.RestTemplate;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * Created by ishare on 2020/02/26.
 */
@Slf4j
@EnableSwagger2
@EnableDiscoveryClient
@SpringBootApplication
public class ChargeWebApplication {


    public static void main(String[] args) {
        try {
            //默认无参启动
            boolean hasProfile = true;
            for (String arg : args) {
                if (arg != null && arg.contains("spring.profiles.active")) {
                    hasProfile = false;
                    break;
                }
            }
            if (hasProfile) {
                List<String> argList = new ArrayList<>();
                if (args.length > 0) {
                    argList.addAll(Arrays.asList(args));
                }
                argList.add("--spring.profiles.active=dev");
                args = argList.toArray(args);
            }
            SpringApplication.run(ChargeWebApplication.class, args);
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    /**
     * 向容器注入一个restTemplate来调用其他子服务，并开启负载均衡
     */
    @Bean
    @LoadBalanced
    RestTemplate restTemplate() {
        return new RestTemplate();
    }

}
